magneticalc.Display_Widget.Display_Widget

# ``magneticalc`.`Display_Widget`.`Display_Widget``

class documentation

`class Display_Widget(QGroupBox2):`

Constructor: `Display_Widget(gui)`

View In Hierarchy

Display_Widget class.

Method | `__init__` | Populates the widget.
Method | `disable_field_labels` | Disables field labels.
Method | `prevent_excessive_field_labels` | Prevents displaying an excessive number of field labels.
Method | `reload` | Reloads the widget.
Method | `set_display_field_magnitude_labels` | Sets field label "Display Magnitude" value.
Method | `set_field_arrow_head_scale` | Sets field arrow head scale.
Method | `set_field_arrow_line_scale` | Sets field arrow line scale.
Method | `set_field_boost` | Sets field boost value.
Method | `set_field_label_resolution` | Sets field label resolution exponent.
Method | `set_field_point_scale` | Sets field point scale.
Method | `update` | Updates this widget.
Method | `update_controls` | Updates the field label resolution combobox.
Method | `update_labels` | Updates the labels.
Class Variable | `ExcessiveFieldLabelsThreshold` | Undocumented
Class Variable | `FieldArrowHeadScaleMax` | Undocumented
Class Variable | `FieldArrowHeadScaleMin` | Undocumented
Class Variable | `FieldArrowHeadScaleStep` | Undocumented
Class Variable | `FieldArrowLineScaleMax` | Undocumented
Class Variable | `FieldArrowLineScaleMin` | Undocumented
Class Variable | `FieldArrowLineScaleStep` | Undocumented
Class Variable | `FieldBoostMax` | Undocumented
Class Variable | `FieldBoostMin` | Undocumented
Class Variable | `FieldBoostStep` | Undocumented
Class Variable | `FieldPointScaleMax` | Undocumented
Class Variable | `FieldPointScaleMin` | Undocumented
Class Variable | `FieldPointScaleStep` | Undocumented
Instance Variable | `display_field_magnitude_labels_checkbox` | Undocumented
Instance Variable | `field_arrow_head_scale_slider` | Undocumented
Instance Variable | `field_arrow_line_scale_slider` | Undocumented
Instance Variable | `field_boost_slider` | Undocumented
Instance Variable | `field_label_resolution_combobox` | Undocumented
Instance Variable | `field_label_resolution_combobox_connection` | Undocumented
Instance Variable | `field_point_scale_slider` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `total_labels_label` | Undocumented

Inherited from `QGroupBox2`:

Method | `set_color` | Sets the style and label color of the groupbox.

Inherited from `QLayouted` (via `QGroupBox2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, gui: `GUI`):
overrides `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.__init__`

Populates the widget.

Parameters
gui: `GUI` | GUI

def disable_field_labels(self):

Disables field labels.

def prevent_excessive_field_labels(self, choice: `bool`):

Prevents displaying an excessive number of field labels.

Parameters
choice: `bool` | True lets the user choose; False disables field labels if there is an excessive number of them

def reload(self):

Reloads the widget.

def set_display_field_magnitude_labels(self, value: `bool`):

Sets field label "Display Magnitude" value.

Parameters
value: `bool` | Value

def set_field_arrow_head_scale(self, value: `float`):

Sets field arrow head scale.

Parameters
value: `float` | Value

def set_field_arrow_line_scale(self, value: `float`):

Sets field arrow line scale.

Parameters
value: `float` | Value

def set_field_boost(self, value: `float`):

Sets field boost value.

Parameters
value: `float` | Value

def set_field_label_resolution(self, value: `int`):

Sets field label resolution exponent.

Parameters
value: `int` | Value

def set_field_point_scale(self, value: `float`):

Sets field point scale.

Parameters
value: `float` | Value

def update(self):

Updates this widget.

def update_controls(self):

Updates the field label resolution combobox.

def update_labels(self):

Updates the labels.

ExcessiveFieldLabelsThreshold: `int` =

Undocumented

FieldArrowHeadScaleMax: `int` =

Undocumented

FieldArrowHeadScaleMin: `int` =

Undocumented

FieldArrowHeadScaleStep =

Undocumented

FieldArrowLineScaleMax: `int` =

Undocumented

FieldArrowLineScaleMin: `int` =

Undocumented

FieldArrowLineScaleStep =

Undocumented

FieldBoostMax: `int` =

Undocumented

FieldBoostMin: `int` =

Undocumented

FieldBoostStep =

Undocumented

FieldPointScaleMax: `int` =

Undocumented

FieldPointScaleMin: `int` =

Undocumented

FieldPointScaleStep =

Undocumented

display_field_magnitude_labels_checkbox =

Undocumented

field_arrow_head_scale_slider =

Undocumented

field_arrow_line_scale_slider =

Undocumented

field_boost_slider =

Undocumented

field_label_resolution_combobox =

Undocumented

field_label_resolution_combobox_connection =

Undocumented

field_point_scale_slider =

Undocumented

gui =

Undocumented

total_labels_label =

Undocumented